Struct wasmer_compiler_cli::store::SubsetTunables
source · pub struct SubsetTunables {
pub static_memory_bound: Pages,
pub static_memory_offset_guard_size: u64,
pub dynamic_memory_offset_guard_size: u64,
}Expand description
Minimul Subset of Tunable parameters for WebAssembly compilation.
Fields
static_memory_bound: PagesFor static heaps, the size in wasm pages of the heap protected by bounds checking.
static_memory_offset_guard_size: u64The size in bytes of the offset guard for static heaps.
dynamic_memory_offset_guard_size: u64The size in bytes of the offset guard for dynamic heaps.
Implementations
sourceimpl SubsetTunables
impl SubsetTunables
sourcepub fn for_target(target: &Target) -> Self
pub fn for_target(target: &Target) -> Self
Get the BaseTunables for a specific Target
sourcepub fn memory_style(&self, memory: &MemoryType) -> MemoryStyle
pub fn memory_style(&self, memory: &MemoryType) -> MemoryStyle
Get a MemoryStyle for the provided MemoryType
sourcepub fn table_style(&self, _table: &TableType) -> TableStyle
pub fn table_style(&self, _table: &TableType) -> TableStyle
Get a TableStyle for the provided TableType.